-------------------
--   Synthesis   --
-------------------

library ieee;
use ieee.math_real.all,ieee.std_logic_1164.all;
use work.biological_systems.all;
use work.all;



entity DsRed_synth is
	generic (Kxa : real := 0.2;
			 Kxr : real := 0.06;
			 ktr : real := 0.18;
			 ktl : real := 0.15;
			 dARNm : real := 0.1;
			 dp : real := 0.1;
			 a : real := 0.0;
			 na : real := 2.0;
			 nr : real := 2.0);
	port (terminal Act_term : Act;
terminal LacI_term : LacI;
terminal miR141_term : miR141;
terminal miR142_term : miR142;
terminal miR146a_term : miR146a;

		  terminal Prot_term : DsRed);
end;

architecture conservative of DsRed_synth is

	constant valr_act : real := 50.0;
	constant valr_rep : real := 50.0;
	constant valc_arnm : real := 1.0;
 
	terminal ARNm_term : DsRed_arnm;

	quantity C_Act across Act_term to Act_cell;
quantity C_LacI across LacI_term to LacI_cell;

	
	quantity CARNm across FARNm through ARNm_term to DsRed_arnm_cell;
	quantity Cprot across Fprot through Prot_term to DsRed_cell;
		
Begin

	r_Act : entity Act_resistor(conservative)
			 generic map (valr_act)
			 port map (a => Act_term, b => Act_cell);

	r_LacI : entity LacI_resistor(conservative)
			 generic map (valr_rep)
			 port map (a => LacI_term, b => LacI_cell);

	rvar_DsRed : entity resvar_DsRed_ARNm_miR141(conservative)
			 generic map (1.0)
			 port map (a => ARNm_term, b => DsRed_ARNm_cell, miR141_term => miR141_term, miR142_term => miR142_term, miR146a_term => miR146a_term);

			
	r_arnm : entity DsRed_arnm_resistor(conservative)
			 generic map (1.0/dARNm)
			 port map (a => ARNm_term, b => DsRed_arnm_cell);
			 
	c_arnm : entity DsRed_arnm_capacitor(conservative)
			 generic map (valc_arnm)
			 port map (a => ARNm_term, b => DsRed_arnm_cell);					   

			 
	r_prot : entity DsRed_resistor(conservative)
			 generic map (1.0/dp)
			 port map (a => Prot_term, b => DsRed_cell);

	
	FARNm == ktr*(a + 1.0/((1.0+(Kxa/(C_Act+1.0e-18))**na)*(1.0+(Kxr/(C_LacI+1.0e-18))**(-nr))));

	
	Fprot == ktl*CARNm;
	
end conservative;

