-------------------
--   Synthesis   --
-------------------

library ieee;
use ieee.math_real.all,ieee.std_logic_1164.all;
use work.biological_systems.all;
use work.all;



entity miR21_synth is
	generic (Kxa : real := 0.2;
			 Kxr : real := 0.02;
			 ktr : real := 0.1;
			 ktl : real := 0.1;
			 dARNm : real := 0.1;
			 dp : real := 0.1;
			 a : real := 0.0;
			 na : real := 2.0;
			 nr : real := 2.0);
	port (terminal miR21_Act_term : miR21_Act;
terminal Rep_term : Rep;

		  terminal Prot_term : miR21);
end;

architecture conservative of miR21_synth is

	constant valr_act : real := 50.0;
	constant valr_rep : real := 10.0;
	constant valc_arnm : real := 1.0;
 
	terminal ARNm_term : miR21_arnm;

	quantity C_miR21_Act across miR21_Act_term to miR21_Act_cell;
quantity C_Rep across Rep_term to Rep_cell;

	
	quantity CARNm across FARNm through ARNm_term to miR21_arnm_cell;
	quantity Cprot across Fprot through Prot_term to miR21_cell;
		
Begin

	r_miR21_Act : entity miR21_Act_resistor(conservative)
			 generic map (valr_act)
			 port map (a => miR21_Act_term, b => miR21_Act_cell);

	r_Rep : entity Rep_resistor(conservative)
			 generic map (valr_rep)
			 port map (a => Rep_term, b => Rep_cell);


			
	r_arnm : entity miR21_arnm_resistor(conservative)
			 generic map (1.0/dARNm)
			 port map (a => ARNm_term, b => miR21_arnm_cell);
			 
	c_arnm : entity miR21_arnm_capacitor(conservative)
			 generic map (valc_arnm)
			 port map (a => ARNm_term, b => miR21_arnm_cell);					   

			 
	r_prot : entity miR21_resistor(conservative)
			 generic map (1.0/dp)
			 port map (a => Prot_term, b => miR21_cell);

	
	FARNm == ktr*(a + 1.0/((1.0+(Kxa/(C_miR21_Act+1.0e-18))**na)*(1.0+(Kxr/(C_Rep+1.0e-18))**(-nr))));

	
	Fprot == ktl*CARNm;
	
end conservative;

