-------------------
--   Synthesis   --
-------------------

library ieee;
use ieee.math_real.all,ieee.std_logic_1164.all;
use work.biological_systems.all;
use work.all;



entity rtTA_synth2 is
	generic (Kxa : real := 0.2;
			 Kxr : real := 0.02;
			 ktr : real := 0.1;
			 ktl : real := 0.1;
			 dARNm : real := 0.1;
			 dp : real := 0.1;
			 a : real := 0.0;
			 na : real := 2.0;
			 nr : real := 2.0);
	port (terminal Act_term : Act;
terminal Rep_term : Rep;
terminal miR17_term : miR17;
terminal miR30a_term : miR30a;

		  terminal Prot_term : rtTA);
end;

architecture conservative of rtTA_synth2 is

	constant valr_act : real := 50.0;
	constant valr_rep : real := 10.0;
	constant valc_arnm : real := 1.0;
 
	terminal ARNm_term : rtTA_arnm;

	quantity C_Act across Act_term to Act_cell;
quantity C_Rep across Rep_term to Rep_cell;

	
	quantity CARNm across FARNm through ARNm_term to rtTA_arnm_cell;
	quantity Cprot across Fprot through Prot_term to rtTA_cell;
		
Begin

	r_Act : entity Act_resistor(conservative)
			 generic map (valr_act)
			 port map (a => Act_term, b => Act_cell);

	r_Rep : entity Rep_resistor(conservative)
			 generic map (valr_rep)
			 port map (a => Rep_term, b => Rep_cell);

	rvar_rtTA : entity resvar_rtTA_ARNm_miR17(conservative)
			 generic map (8.0)
			 port map (a => ARNm_term, b => rtTA_ARNm_cell, miR17_term => miR17_term, miR30a_term => miR30a_term);

			
	r_arnm : entity rtTA_arnm_resistor(conservative)
			 generic map (1.0/dARNm)
			 port map (a => ARNm_term, b => rtTA_arnm_cell);
			 
	c_arnm : entity rtTA_arnm_capacitor(conservative)
			 generic map (valc_arnm)
			 port map (a => ARNm_term, b => rtTA_arnm_cell);					   

			 
	r_prot : entity rtTA_resistor(conservative)
			 generic map (1.0/dp)
			 port map (a => Prot_term, b => rtTA_cell);

	
	FARNm == ktr*(a + 1.0/((1.0+(Kxa/(C_Act+1.0e-18))**na)*(1.0+(Kxr/(C_Rep+1.0e-18))**(-nr))));

	
	Fprot == ktl*CARNm;
	
end conservative;

